## CSS - Demos - Typography

<script type="module" src="/web_components/js/css/demos/WebC__CSS__Demo__Typography.mjs"></script>

<webc-container>
    <webc-css-demo-typography                            ></webc-css-demo-typography>  <!-- No framework applied -->
    <webc-css-demo-typography framework="bootstrap"      ></webc-css-demo-typography>
    <webc-css-demo-typography framework="foundation"     ></webc-css-demo-typography> 
    <webc-css-demo-typography framework="material-design"></webc-css-demo-typography>
    <webc-css-demo-typography framework="tailwind"       ></webc-css-demo-typography>
    
</webc-container>